@@ -1,7 +1,7 @@
 class Account:
 
-    def __init__(self, id, url, bio, reputation, created, pro_expiration):
-        self.id = id
+    def __init__(self, account_id, url, bio, reputation, created, pro_expiration):
+        self.id = account_id
         self.url = url
         self.bio = bio
         self.reputation = reputation
