@@ -1,7 +1,7 @@
 class Message:
 
-    def __init__(self, id, from_user, account_id, sender_id, body, conversation_id, datetime):
-        self.id = id
+    def __init__(self, message_id, from_user, account_id, sender_id, body, conversation_id, datetime):
+        self.id = message_id
         self.from_user = from_user
         self.account_id = account_id
         self.sender_id = sender_id
